@@ -2,12 +2,10 @@
 ### Basic IO functions for working with Rasters ###
 
 This module does standard raster operations related to read, write, and metadata.
-
-TODO:
-    * Copy, seperate, expand, create, delete
-    * Refactor logic in ready_io_raster
 """
 
+# TODO: Copy, seperate, expand, create, delete
+
 # Standard library
 import sys; sys.path.append("../../")
 import os
@@ -87,7 +85,7 @@ def open_raster(raster, *, writeable=True, allow_lists=True):
 def get_projection(raster, wkt=True):
     """ Gets the projection as WKT from a dataset. Path or gdal.Dataset. """
     dataset = open_raster(raster)
-    
+
     if wkt:
         return dataset.GetProjectionRef()
     else:
@@ -177,6 +175,7 @@ def _raster_to_metadata(raster):
         "is_raster": True,
         "is_vector": False,
         "bbox": bbox_ogr,
+        "extent": bbox_ogr,
     }
 
     for key, value in bboxes.items():
@@ -188,7 +187,8 @@ def _raster_to_metadata(raster):
 
     def get_bbox_as_vector_latlng():
         projection_osr_latlng = osr.SpatialReference()
-        projection_osr_latlng.ImportFromEPSG(4326)
+        # projection_osr_latlng.ImportFromEPSG(4326)
+        projection_osr_latlng.ImportFromWkt('GEOGCS["WGS 84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.257223563]],PRIMEM["Greenwich",0],UNIT["degree",0.0174532925199433,AUTHORITY["EPSG","9122"]],AUTHORITY["EPSG","4326"]]')
 
         return bbox_utils.convert_bbox_to_vector(metadata["bbox_latlng"], projection_osr_latlng)
 
